<template>
	<view>
		<!-- <uni-forms ref="formData" :modelValue="formData" label-width="120"> -->
		<uni-forms class="customcss" label-width="120">
			<uni-forms-item label="托盘条码">
				<uni-easyinput type="text" :focus="!barcodefocus" v-model="barcode" placeholder="请扫描托盘条码" ref='midInput'
					@input="locationNoinputChange()" @confirm="submit" />
			</uni-forms-item>
			<uni-forms-item label="货位编号">
				<uni-easyinput type="text" :focus="barcodefocus" v-model="locationNo" placeholder="请输入货位编号"
					ref='midInput' @confirm="submit" />
			</uni-forms-item>

			<uni-forms-item>
				<button @click="confirm" type="primary" size="default" style="margin-top: 2%;">数量确认</button>
			</uni-forms-item>
			<uni-forms-item>
				<button @click="submit" type="primary" size="default" style="margin-top: 2%;">手动绑定</button>
			</uni-forms-item>
		</uni-forms>
		<u-toast ref="uToast" />
	</view>
</template>

<script>
	export default {
		data() {
			return {
				locationNo: "",
				barcode: '',
				barcodefocus: false,
			}
		},
		onLoad(res) {},
		methods: {
			confirm(){
				if (this.barcode == "") {
					this.$refs.uToast.show({
						title: "托盘号不能为空",
						type: "error"
					});
					return;
				}
				var postData = {
					MainData: {
						"trainCode": this.locationNo,
					},
				}
				this.$u.post('/api/StockOperate/TrainStockBindConfirm', postData).then((res) => {
					if (res.status) {
						this.items = [];
						this.$refs.uToast.show({
							title: res.message,
							type: "success"
						});
						this.locationNo = "";
						this.barcode = "";
						this.barcodefocus = false;
					} else {
						this.$refs.uToast.show({
							title: res.message,
							type: "error"
						});
					}
				})
			},
			submit() {
				if (this.locationNo == "") {
					this.$refs.uToast.show({
						title: "货位号不能为空",
						type: "error"
					});
					return;
				}
				if (this.barcode == "") {
					this.$refs.uToast.show({
						title: "托盘号不能为空",
						type: "error"
					});
					return;
				}
				var postData = {
					MainData: {
						"trainCode": this.locationNo,
						"barcode": this.barcode
					},
				}
				this.$u.post('/api/StockOperate/TrainStockBind', postData).then((res) => {
					if (res.status) {
						this.items = [];
						this.$refs.uToast.show({
							title: res.message,
							type: "success"
						});
						this.locationNo = "";
						this.barcode = "";
						this.barcodefocus = false;
					} else {
						this.$refs.uToast.show({
							title: res.message,
							type: "error"
						});
					}
				})
			},
			locationNoinputChange() {
				this.barcodefocus = false;
				this.$nextTick(function(x) {
					if (this.barcode != '') {
						this.barcodefocus = true;
					}
				})
			}
		}
	}
</script>

<style lang="scss">
	@import '@/common/uni-ui.scss';

	page {
		display: flex;
		flex-direction: column;
		box-sizing: border-box;
		background-color: #efeff4;
		min-height: 100%;
		height: auto;
	}

	.tips {
		color: #67c23a;
		font-size: 14px;
		line-height: 40px;
		text-align: center;
		background-color: #f0f9eb;
		height: 0;
		opacity: 0;
		transform: translateY(-100%);
		transition: all 0.3s;
	}

	.tips-ani {
		transform: translateY(0);
		height: 40px;
		opacity: 1;
	}

	.content {
		width: 100%;
		display: flex;
	}

	.list-picture {
		width: 100%;
		height: 145px;
	}

	.thumb-image {
		width: 100%;
		height: 100%;
	}

	.ellipsis {
		display: flex;
		overflow: hidden;
	}

	.uni-ellipsis-1 {
		overflow: hidden;
		white-space: nowrap;
		text-overflow: ellipsis;
	}

	.uni-ellipsis-2 {
		overflow: hidden;
		text-overflow: ellipsis;
		display: -webkit-box;
		-webkit-line-clamp: 2;
		-webkit-box-orient: vertical;
	}

	.customcss {
		background-color: #fff;
		padding: 20rpx 40rpx;
		width: 100%;
	}

	.footer {
		padding-top: 50%;
	}
</style>